import locale from "./../locale";
import destroy from "./destroy";

// 弹出对话框
export default function confirm(_ref) {
  var portal = _ref.portal,
    maskClosable = _ref.maskClosable,
    onVisibleChange = _ref.onVisibleChange,
    maskProps = _ref.maskProps,
    captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    content = _ref.content;
  var mask = null;

  // 确定按钮
  if (submitProps === undefined) {
    // eslint-disable-next-line
    submitProps = {
      onClick: function onClick() {}
    };
  }

  // 取消按钮
  if (cancelProps === undefined) {
    // eslint-disable-next-line
    cancelProps = {
      onClick: function onClick() {}
    };
  }

  // 更新属性
  function updateAttribute(mask) {
    var _submitProps, _submitProps2, _cancelProps, _cancelProps2;
    // 更新遮罩
    mask.setAttribute('style', '');
    mask.setAttribute('class', 'mask modal-mask');
    if (maskProps) {
      var maskStyle = maskProps.style,
        maskClassName = maskProps.className;
      if (maskStyle) {
        for (var stylePropName in maskStyle) {
          mask.style[stylePropName] = maskStyle[stylePropName];
        }
      }
      if (maskClassName) {
        mask.className = "mask modal-mask".concat(maskClassName ? ' ' + maskClassName : '');
      }
    }

    // 更新标题
    if (captionProps !== null && captionProps !== void 0 && captionProps.caption) {
      mask.querySelector('.modal-caption').classList.remove('hide');
      mask.querySelector('.modal-caption').innerHTML = captionProps.caption;
    } else {
      mask.querySelector('.modal-caption').classList.add('hide');
    }

    // 更新内容
    if (content) {
      mask.querySelector('.modal-content').innerHTML = content;
    } else {
      mask.querySelector('.modal-content').innerHTML = '';
    }

    // 提交按钮
    if ((_submitProps = submitProps) !== null && _submitProps !== void 0 && _submitProps.onClick || (_submitProps2 = submitProps) !== null && _submitProps2 !== void 0 && _submitProps2.caption) {
      var _submitProps3;
      mask.querySelector('.modal-ok').classList.remove('hide');
      mask.querySelector('.modal-ok').innerHTML = ((_submitProps3 = submitProps) === null || _submitProps3 === void 0 ? void 0 : _submitProps3.caption) || locale('确定', 'ok');
    } else {
      mask.querySelector('.modal-ok').classList.add('hide');
    }

    // 取消按钮
    if ((_cancelProps = cancelProps) !== null && _cancelProps !== void 0 && _cancelProps.onClick || (_cancelProps2 = cancelProps) !== null && _cancelProps2 !== void 0 && _cancelProps2.caption) {
      var _cancelProps3;
      mask.querySelector('.modal-cancel').classList.remove('hide');
      mask.querySelector('.modal-cancel').innerHTML = ((_cancelProps3 = cancelProps) === null || _cancelProps3 === void 0 ? void 0 : _cancelProps3.caption) || locale('取消', 'cancel');
    } else {
      mask.querySelector('.modal-cancel').classList.add('hide');
    }

    // 更新事件中用到的属性（否则事件中将永远读取到的是闭包中的属性，即上次的属性）
    mask.maskClosable = maskClosable;
    mask.submitProps = submitProps;
    mask.cancelProps = cancelProps;
    mask.onVisibleChange = onVisibleChange;

    // dom透传
    if (toString.call(portal).indexOf('HTML') !== -1) {
      portal.appendChild(mask);
    } else {
      ;
      (document.getElementById('root') || document.body).appendChild(mask);
    }
  }

  // 点击遮罩
  function handleMaskClick(e) {
    var _mask, _mask2;
    // 读取更新后的属性
    var maskClosable = (_mask = mask) === null || _mask === void 0 ? void 0 : _mask.maskClosable;
    var onVisibleChange = (_mask2 = mask) === null || _mask2 === void 0 ? void 0 : _mask2.onVisibleChange;
    if (maskClosable) {
      if (onVisibleChange) onVisibleChange(false);
      destroy(e.currentTarget);
    }
    e.stopPropagation();
  }

  // 点击确定或者取消按钮
  function handleButtonClick(e) {
    var _mask3, _mask4, _mask5;
    var currentTarget = e.currentTarget;
    var isOk = currentTarget.classList.contains('modal-ok');

    // 读取更新后的属性
    var buttonProps = isOk ? (_mask3 = mask) === null || _mask3 === void 0 ? void 0 : _mask3.submitProps : (_mask4 = mask) === null || _mask4 === void 0 ? void 0 : _mask4.cancelProps;
    var onVisibleChange = (_mask5 = mask) === null || _mask5 === void 0 ? void 0 : _mask5.onVisibleChange;
    if (typeof (buttonProps === null || buttonProps === void 0 ? void 0 : buttonProps.onClick) === 'function') {
      var _buttonProps$onClick;
      var close = (_buttonProps$onClick = buttonProps.onClick()) !== null && _buttonProps$onClick !== void 0 ? _buttonProps$onClick : true;
      if (close) {
        if (onVisibleChange) onVisibleChange(false);
        destroy(e.currentTarget.closest('.modal-mask'));
      }
    } else {
      if (onVisibleChange) onVisibleChange(false);
      destroy(e.currentTarget.closest('.modal-mask'));
    }
    e.stopPropagation();
  }

  // 渲染
  function render() {
    var modalId = '__SeedsUI_modal_el__';
    // 如果没生成成功, 则强制生成
    var container = document.body;
    if (toString.call(portal).indexOf('HTML') !== -1) {
      container = portal;
    }
    mask = container.querySelector('#' + modalId);
    if (!mask) {
      // 创建dom
      mask = document.createElement('div');
      mask.setAttribute('class', "mask modal-mask");
      mask.setAttribute('id', modalId);
      mask.innerHTML = "\n        <div class=\"popup-animation modal modal-alert middle\" data-animation=\"zoom\">\n          <div class=\"modal-body\">\n            <div class=\"modal-caption hide\"></div>\n            <div class=\"modal-content\"></div>\n          </div>\n          <div class=\"modal-footer\">\n            <div class=\"modal-cancel button\"></div>\n            <div class=\"modal-ok button\"></div>\n          </div>\n        </div>\n      "

      // 添加到dom上
      ;
      (container || document.getElementById('root') || document.body).appendChild(mask);

      // 绑定事件
      attach(mask);
    }

    // 更新属性
    updateAttribute(mask);

    // 渲染完成后补充active, 解决渲染后动画不生效的问题
    setTimeout(function () {
      mask = container.querySelector('#' + modalId);
      if (!mask) return;
      // 如果正在移除，则停止移除
      if (mask.timeout) {
        window.clearTimeout(mask.timeout);
      }
      // 动画显示
      mask.classList.add('active');
      mask.querySelector('.modal-alert').classList.add('active');
    }, 10);
    return mask;
  }

  // 绑定事件
  function attach(mask) {
    var _submitProps4, _submitProps5, _cancelProps4, _cancelProps5;
    var okBtn = mask.querySelector('.modal-ok');
    var cancelBtn = mask.querySelector('.modal-cancel');

    // 绑定事件
    mask.removeEventListener('click', handleMaskClick, false);
    mask.addEventListener('click', handleMaskClick, false);
    if ((_submitProps4 = submitProps) !== null && _submitProps4 !== void 0 && _submitProps4.onClick || (_submitProps5 = submitProps) !== null && _submitProps5 !== void 0 && _submitProps5.caption) {
      okBtn.removeEventListener('click', handleButtonClick, false);
      okBtn.addEventListener('click', handleButtonClick, false);
    }
    if ((_cancelProps4 = cancelProps) !== null && _cancelProps4 !== void 0 && _cancelProps4.onClick || (_cancelProps5 = cancelProps) !== null && _cancelProps5 !== void 0 && _cancelProps5.caption) {
      cancelBtn.removeEventListener('click', handleButtonClick, false);
      cancelBtn.addEventListener('click', handleButtonClick, false);
    }
  }

  // 渲染与绑定事件
  render();
  return mask;
}